@@ -48,6 +48,7 @@ def base_menu():
     qs time                  :-> view current time
     qs pact                  :-> output string in clipboard
     qs fcopy <file>          :-> copy file content to clipboard
+    qs copy <file>           :-> copy file to clipboard
     qs user_lang             :-> Get User Language in .qsrc
     qs play <file...>        :-> Play Musics""") \
         if user_lang != 'zh' else color_rep("""基础工具:
@@ -58,6 +59,7 @@ def base_menu():
     qs time                  :-> 查看当前时间
     qs pcat                  :-> 输出粘贴板内容
     qs fcopy <文件>          :-> 拷贝文件内容到粘贴板
+    qs copy <文件>           :-> 拷贝文件到粘贴板
     qs user_lang             :-> 获取用户的默认语言
     qs play <文件...>        :-> 播放音乐""")
 
@@ -230,7 +232,8 @@ basic_funcs = {
     'pcat': 'pcat',
     'fcopy': 'fcopy',
     'user_lang': 'get_user_lang',
-    'play': 'play_music'
+    'play': 'play_music',
+    'copy': 'copy'
 }
 
 system_funcs = {
