@@ -13,9 +13,10 @@ def upgrade():
 
     Upgrade qs
     """
-    import os
-    if os.system('pip3 install QuickStart-Rhy --upgrade'):
-        os.system('pip install QuickStart-Rhy --upgrade')
+    from . import external_exec, user_pip, qs_default_console, qs_info_string
+    with qs_default_console.status('正在更新'):
+        external_exec(f'{user_pip} install QuickStart-Rhy --upgrade', True)
+    qs_default_console.print(qs_info_string, '更新完成')
 
 
 def m3u8_dl(url):
